$(document).ready(function () {

    $('#myTable').DataTable({
        "scrollX": true,
        "order": [],
        "columns": [
            { "data": "employee_id" },
            { "data": "name_full" },
            { "data": "date" },
            { "data": "view", className: "view" },
        ],
        columnDefs: [
            { width: 100, targets: 0 },
            { width: 100, targets: 2 },
            { width: 30, targets: 3 },
        ],
    });



    $('input[name="txtDateFrom"]').daterangepicker({
        singleDatePicker: true,
        showDropdowns: true,
        locale: {
            format: 'YYYY-MM-DD',
        }

    });

    $('input[name="txtDateTo"]').daterangepicker({
        singleDatePicker: true,
        showDropdowns: true,
        locale: {
            format: 'YYYY-MM-DD',
        }

    });

    employees();



    $('#btnSearch').on('click', function () {
        search($('#txtEmployee').optionID(), $('#txtDateFrom').val(), $('#txtDateTo').val());
    });

});




function employees() {

    $.ajax({
        type: "GET",
        url: "/st/employeeActivity/employees",
        processData: false,
        contentType: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () {

        },
        success: function (response) {
            console.log(response);

            if (response.data.success) {
                $('#txtEmployee').setData(response.data.result);

            } else {
                showErrorMessage();
            }
        },
        error: function (error) {
            console.log(error);
            showErrorMessage();

        },
        complete: function () {

        }

    });
}



function search(id, date_from, date_to) {

    $.ajax({
        type: "GET",
        url: "/st/employeeActivity/search/" + id + "/" + date_from + "/" + date_to,
        processData: false,
        contentType: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () {

        },
        success: function (response) {
            console.log(response);

            if (response.data.success) {
                var data = [];

                for (i = 0; i < response.data.result.length; i++) {
                    var id = response.data.result[i]['employee_id'];
                    var name = response.data.result[i]['name_withinitial'];
                    var date = response.data.result[i]['created_at'];
                    var rand_id = response.data.result[i]['rand_id'];


                    data.push({
                        "employee_id": id,
                        "name_full": name,
                        "date": date,
                        "view": '<button class="btn btn-success" onclick="view(' + rand_id + ')"><i class="fa fa-eye" aria-hidden="true"></i></button>',
                    });
                }

                var table = $('#myTable').DataTable();
                table.clear();
                table.rows.add(data).draw();

            } else {
                showErrorMessage();
            }
        },
        error: function (error) {
            console.log(error);
            showErrorMessage();

        },
        complete: function () {

        }

    });
}


function view(id) {
    $.ajax({
        type: "GET",
        url: "/st/employeeActivity/employeeRecordHistory/" + id,
        processData: false,
        contentType: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () {

        },
        success: function (response) {
            console.log(response);

            if (response.data.success) {
                var result = response.data.result;
                if (result) {
                    $('#lblUpdated').text(result[0].updated_by);
                    $('#lblUpdatedAt').text(result[0].created_at);

                    var tbody = "";
                    for (var i = 0; i < result.length; i++) {

                        if (result[i].new_value != result[i].old_value && result[i].field_name != "") {
                            var row = "<tr>";
                            row += "<td>" + result[i].field_name + "</td>";
                            row += "<td>" + result[i].new_value + "</td>";
                            row += "<td>" + result[i].old_value + "</td>";
                            row += "</tr>"
                            tbody += row;
                        }

                    }

                    $('#tblHistory').empty();
                    $('#tblHistory').append(tbody);
                }

                $("#searchModal").modal('toggle');

            } else {
                showErrorMessage();
            }
        },
        error: function (error) {
            console.log(error);
            showErrorMessage();

        },
        complete: function () {

        }

    });
}




/**
* showSuccessMessage
* This function is used to show success message.
* @param message This is the paramter to require message content
*/
function showSuccessMessage(message) {
    toastr.success(message);
}


/**
* showWarningMessage
* This function is used to show warning message.
* @param message This is the paramter to require message content
*/
function showWarningMessage(message) {
    toastr.warning(message);
}



/**
* showErrorMessage
* This function is used to show error message.
* @param message This is the paramter to require message content
*/
function showErrorMessage() {
    toastr.error('Something went wrong');
}
