var permission_id = 0;
$(document).ready(function () {
    $('#tblPermission').DataTable({
        "scrollX": true,
        "order": [],
        "columns": [
            { "data": "permission" },
            { "data": "edit" },
            { "data": "delete" },
            { "data": "status" },
        ],
        columnDefs: [
            { width: 30, targets: 1 },
            { width: 30, targets: 2 },
            { width: 30, targets: 3 },
        ],
    });


    allModules();
    allPermission();


    $('#btnPermissionAction').click(function () {
        var event = $('#btnPermissionAction').text();
        if (event == 'Save') {
            savePermission();
        }else if(event == 'Update'){
            updatePermission(permission_id);
        }

    });

});



function showPermissionModal() {
    $('#txtPermission').val('');
    $('#txtSlug').val('');
    setSelectedOption('cmbModule',1);
    $('#btnPermissionAction').text('Save');
    $('#permissionModal').modal('toggle');
}


function closePermissionModal() {
    $('#permissionModal').modal('hide');
}


function editPermission(id) {
    getPermission(id);
}




function allModules() {
    $.ajax({
        type: "GET",
        url: "/st/user/permission/allModule",
        processData: false,
        contentType: false,
        async: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () {

        },
        success: function (response) {
            console.log(response);
            if (response.data.success) {
                $('#cmbModule').empty();
                var result = response.data.result;
                for (i = 0; i < result.length; i++) {
                    $('#cmbModule').append('<option value="' + result[i].id + '">' + result[i].module_name + '</option>');
                }

            } else {
                showErrorMessage();
            }

        },
        error: function (error) {
            console.log(error);
            showErrorMessage();

        },
        complete: function () {

        }

    });
}




/** Save Permission */

function savePermission() {

    $.ajax({
        type: "POST",
        url: '/st/user/permission/savePermission',
        data: $('#permissionForm').serialize(),
        processData: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () {

        },
        success: function (response) {
            console.log(response);
            if (response.data.success) {
                showSuccessMessage('Permission has been saved successfully...');
                closePermissionModal();
                allPermission();

            } else {
                showErrorMessage();
            }


        },
        error: function (error) {
            console.log(error);

        },
        complete: function () {

        }

    });

}





/** Get all permission records from db */
function allPermission() {
    $.ajax({
        type: "GET",
        url: "/st/user/permission/allPermission",
        processData: false,
        contentType: false,
        async: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () {

        },
        success: function (response) {
            console.log(response);
            if (response.data.success) {
                appendTableRow(response.data.result);

            } else {
                showErrorMessage();
            }

        },
        error: function (error) {
            console.log(error);
            showErrorMessage();

        },
        complete: function () {

        }

    });
}




function appendTableRow(result) {

    var data = [];
    for (i = 0; i < result.length; i++) {


        var id = result[i]['id'];
        var permission = result[i]['name'];
        var slug = result[i]['slug'];
        var status = result[i]['status'];
        var string_id = "'" + id + "'";



        var switch_slider = '<label class="switch"><input type="checkbox" id=' + "swt" + id + ' name="status"   onchange="disable(' + string_id + ')"><span class="slider round"></span></label>';
        if (status == '1') {
            switch_slider = '<label class="switch"><input type="checkbox" id=' + "swt" + id + ' name="status" checked  onchange="disable(' + string_id + ')"><span class="slider round"></span></label>';
        }

        data.push({
            "permission": permission,
            "edit": '<button class="btn btn-primary" onclick="editPermission(' + id + ')"><i class="fa fa-pencil-square-o" aria-hidden="true"></i></button>',
            "delete": '<button class="btn btn-danger" onclick="deletePermission(' + id + ')"><i class="fa fa-trash" aria-hidden="true"></i></button>',
            "status": switch_slider,
        });

    }



    var table = $('#tblPermission').DataTable();
    table.clear();
    table.rows.add(data).draw();

}




function deletePermission(id) {


    $.ajax({
        type: 'DELETE',
        url: '/st/user/permission/deletePermission/' + id,
        data: {
            _token: $('input[name=_token]').val()
        },
        timeout: 800000,
        beforeSend: function () {

        },
        success: function (response) {
            console.log(response);
            if (response.data.success) {
                showSuccessMessage('Permission has been deleted successfully...');
                allPermission();

            } else {
                showErrorMessage();
            }
        },
        error: function (error) {
            console.log(error);
            showErrorMessage();
        },
        complete: function () {

        }

    });
}





/** Get permission role from db */
function getPermission(id) {
    $.ajax({
        type: "GET",
        url: "/st/user/permission/getPermission/" + id,
        processData: false,
        contentType: false,
        async: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () {

        },
        success: function (response) {
            console.log(response);
            if (response.data.success) {
                var permission = response.data.result;
                showPermissionModal();
                permission_id = permission.id;
                $('#txtPermission').val(permission.name);
                $('#txtSlug').val(permission.slug);
                setSelectedOption('cmbModule', permission.module_id);
                $('#btnPermissionAction').text('Update');

            } else {
                showErrorMessage();
            }

        },
        error: function (error) {
            console.log(error);
            showErrorMessage();

        },
        complete: function () {

        }

    });
}



/** Update permission*/
function updatePermission(id) {

    $.ajax({
        type: 'PUT',
        url: '/st/user/permission/updatePermission/' + id,
        data: $('#permissionForm').serialize(),
        timeout: 800000,
        beforeSend: function () {

        },
        success: function (response) {
            console.log(response);
            if (response.data.success) {
                showSuccessMessage('Permission has been updated successfully...');
                closePermissionModal();
                allPermission();

            } else {
                showErrorMessage();
            }

        },
        error: function (error) {
            console.log(error);
            showErrorMessage();
        },
        complete: function () {

        }

    });
}



function setSelectedOption(id, valueToSelect) {
    let element = document.getElementById(id);
    element.value = valueToSelect;
}


/**
* showSuccessMessage
* This function is used to show success message.
* @param message This is the paramter to require message content
*/
function showSuccessMessage(message) {
    toastr.success(message);
}


/**
* showWarningMessage
* This function is used to show warning message.
* @param message This is the paramter to require message content
*/
function showWarningMessage(message) {
    toastr.warning(message);
}



/**
* showErrorMessage
* This function is used to show error message.
* @param message This is the paramter to require message content
*/
function showErrorMessage() {
    toastr.error('Something went wrong');
}